@@ -38,15 +38,15 @@ _patch_init_template = """
 
 {0}# start delvewheel patch
 def _delvewheel_init_patch_{1}():
+    import ctypes
     import os
     import sys
     libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, {2!r}))
     is_pyinstaller = getattr(sys, 'frozen', False) and hasattr(sys, '_MEIPASS')
-    if sys.version_info[:2] >= (3, 8) and not os.path.exists(os.path.join(sys.base_prefix, 'conda-meta')) or sys.version_info[:2] >= (3, 10):
+    if sys.version_info[:2] >= (3, 8) and not hasattr(ctypes.pythonapi, 'Anaconda_GetVersion') or sys.version_info[:2] >= (3, 10):
         if not is_pyinstaller or os.path.isdir(libs_dir):
             os.add_dll_directory(libs_dir)
     else:
-        from ctypes import WinDLL
         load_order_filepath = os.path.join(libs_dir, {3!r})
         if not is_pyinstaller or os.path.isfile(load_order_filepath):
             with open(os.path.join(libs_dir, {3!r})) as file:
@@ -54,7 +54,7 @@ def _delvewheel_init_patch_{1}():
             for lib in load_order:
                 lib_path = os.path.join(os.path.join(libs_dir, lib))
                 if not is_pyinstaller or os.path.isfile(lib_path):
-                    WinDLL(lib_path)
+                    ctypes.WinDLL(lib_path)
 
 
 _delvewheel_init_patch_{1}()
@@ -242,11 +242,10 @@ class WheelRepair:
             size = len(contents)
             return hash, size
 
-    @staticmethod
-    def _hashfile(afile: typing.BinaryIO, blocksize: int = 65536, length: int = 32) -> str:
+    def _hashfile(self, afile: typing.BinaryIO, blocksize: int = 65536, length: int = 32) -> str:
         """Hash the contents of an open file handle with SHA256. Return the
         first length characters of the hash."""
-        hasher = hashlib.sha256()
+        hasher = hashlib.sha256(self._distribution_name.encode())
         buf = afile.read(blocksize)
         while len(buf) > 0:
             hasher.update(buf)
